package org.pentaho.platform.web.http.security;

import javax.servlet.http.HttpServletRequest;

import org.springframework.security.ui.preauth.j2ee.J2eePreAuthenticatedProcessingFilter;

/**
 * Optionally removes Windows domain from incoming username.
 * 
 * @author mlowery
 */
public class WindowsPreAuthenticatedProcessingFilter extends J2eePreAuthenticatedProcessingFilter {

  private boolean stripDomain = true;

  @Override
  protected Object getPreAuthenticatedPrincipal(final HttpServletRequest httpRequest) {
    String username = httpRequest.getUserPrincipal() == null ? null : httpRequest.getUserPrincipal().getName();
    if (username != null && stripDomain) {
      int backslashIndex = username.indexOf('\\');
      if (backslashIndex >= 0) {
        logger.debug("stripping domain"); //$NON-NLS-1$
        username = username.substring(backslashIndex + 1);
      }
    }
    if (logger.isDebugEnabled()) {
      logger.debug("Windows PreAuthenticated J2EE principal: " + username); //$NON-NLS-1$
    }
    return username;
  }

  /**
   * Sets the strip domain behavior. Default is true.
   * 
   * @param stripDomain whether or not to strip the domain
   */
  public void setStripDomain(final boolean stripDomain) {
    this.stripDomain = stripDomain;
  }

}
